schubertpy: Operations on the Grassmannian: quantum Pieri rules, quantum Giambelli formulae, manipulation of Schubert classes
=============================================================================================================================

Description
-----------

This Python module facilitates operations such as quantum Pieri rules, quantum Giambelli formulae, action and multiplication of Schubert classes, and conversion between different representations of Schubert classes

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/schubertpy/
